const path = require('path')
const {
  VueLoaderPlugin
} = require('vue-loader')
const ProgressBarPlugin = require('progress-bar-webpack-plugin')

const webpack = require('webpack')
module.exports = {

  context: path.resolve(__dirname, ''),
  entry: {
    popup: path.resolve(__dirname, '../src/popup/main.js'),
    newtab: path.resolve(__dirname, '../src/newtab/main.js'),
    background: path.resolve(__dirname, '../src/background/main.js'),
    'content-script': path.resolve(__dirname, '../src/content-script/main.js'),
    inject: path.resolve(__dirname, '../src/inject/main.js'),
  },
  output: {
    filename: 'js/[name].js',
    chunkFilename: 'js/[name].js',
    path: path.resolve(__dirname, '../chrome/dist/'),
    publicPath: '/chrome/dist/'
  },
  plugins: [
    new VueLoaderPlugin(),
    new ProgressBarPlugin(),
    new webpack.DefinePlugin({
      'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV)
    })
  ],
  resolve: {
    extensions: ['.vue', '.js', '.json'],
    alias: {
      css: path.resolve(__dirname, '../src/css'),
      font: path.resolve(__dirname, '../src/font')
    }
  },
  performance: {
    hints: false
  },
  module: {
    rules: [{
      test: /\.vue$/,
      loader: 'vue-loader'
    },
    {
      test: /\.js$/,
      use: {
        loader: 'babel-loader'
      }
    },
    {
      test: /\.(css|less)$/,
      use: [
        'vue-style-loader',
        'css-loader',
        'postcss-loader',
        'less-loader'
      ]
    },
    {
      test: /\.(png|jpe?g|gif)$/i,
      use: [{
        loader: 'url-loader',
        options: {
          name: '[hash].[ext]',
          outputPath: 'images',
          esModule: false,
          limit: 4096
        }
      }]
    },
    {
      test: /\.(woff|woff2|eot|ttf|otf|TTF)$/,
      use: [{
        loader: 'file-loader',
        options: {
          name: '[hash].[ext]',
          outputPath: 'font'
        }
      }]
    },
    {
      test: /\.(csv|tsv)$/,
      use: ['csv-loader']
    },
    {
      test: /\.xml$/,
      use: ['xml-loader']
    }
    ]
  }
}
